.. _debops.ansible:

debops.ansible
==============

The ``debops.ansible`` role can be used to install Ansible on a Debian or
Ubuntu host. Ansible will be installed either from the OS repositories, from
Ansible upstream APT repository, or using a locally built ``.deb`` package.

.. toctree::
   :maxdepth: 2

   getting-started
   defaults/main

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/debops.ansible/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
